@@ -23,6 +23,8 @@ class SilkyConfig(six.with_metaclass(Singleton, object)):
         'SILKY_PERMISSIONS': default_permissions,
         'SILKY_MAX_REQUEST_BODY_SIZE': -1,
         'SILKY_MAX_RESPONSE_BODY_SIZE': -1,
+        'SILKY_INTERCEPT_PERCENT': 100,
+        'SILKY_PYTHON_PROFILER': False,
     }
 
     def _setup(self):
@@ -40,4 +42,4 @@ class SilkyConfig(six.with_metaclass(Singleton, object)):
         return self.attrs.get(item, None)
 
     def __setattribute__(self, key, value):
-        self.attrs[key] = value
\ No newline at end of file
+        self.attrs[key] = value
