@@ -10,4 +10,6 @@ from silk.tests.test_end_points import *
 from silk.tests.test_config_auth import *
 from silk.tests.test_config_max_body_size import *
 from silk.tests.test_config_meta import *
-from silk.tests.test_view_sql_detail import *
\ No newline at end of file
+from silk.tests.test_view_sql_detail import *
+from silk.tests.test_filters import *
+from silk.tests.test_encoding import *
\ No newline at end of file
